@@ -20,17 +20,9 @@ import types
 
 py_impl = getattr(platform, 'python_implementation', lambda: None)
 PYPY = py_impl() == 'PyPy'
-PURE_PYTHON = os.environ.get('PURE_PYTHON', False)
+PURE_PYTHON = os.environ.get('PURE_PYTHON', PYPY)
 
-if sys.version_info[0] < 3: #pragma NO COVER
-
-    from StringIO import StringIO
-    import cPickle as _pickle
-
-    reload = reload
-
-    def _u(s):
-        return unicode(s, 'unicode_escape')
+if sys.version_info[0] < 3: # pragma: no cover
 
     CLASS_TYPES = (type, types.ClassType)
     _BUILTINS = '__builtin__'
@@ -38,17 +30,7 @@ if sys.version_info[0] < 3: #pragma NO COVER
     PYTHON3 = False
     PYTHON2 = True
 
-    TEXT = unicode
-
-else: #pragma NO COVER
-
-    from io import StringIO
-    import pickle as _pickle
-
-    from imp import reload
-
-    def _u(s):
-        return s
+else: # pragma: no cover
 
     CLASS_TYPES = (type,)
     _BUILTINS = 'builtins'
@@ -56,6 +38,5 @@ else: #pragma NO COVER
     PYTHON3 = True
     PYTHON2 = False
 
-    TEXT = str
 
-_BLANK = _u('')
+_BLANK = u''
